summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMAY <[email protected]>2025-11-29 22:10:37 +0100
committerMAY <[email protected]>2025-11-29 22:10:37 +0100
commit04d43112de4ceecfcf01139a7e2ed759772cb82f (patch)
tree0c50050c30ef27c5d317a861487a7dfd32871e83
parent99d7cfb39d6d4f99ff69a58513814cfedfda1d36 (diff)
refer to UX prefix to avoid compilation issue in standalone mode
-rw-r--r--common/core/src/ux_utility_debug_log.c10
1 files changed, 7 insertions, 3 deletions
diff --git a/common/core/src/ux_utility_debug_log.c b/common/core/src/ux_utility_debug_log.c
index c72d02b..34b4172 100644
--- a/common/core/src/ux_utility_debug_log.c
+++ b/common/core/src/ux_utility_debug_log.c
@@ -62,7 +62,7 @@
/* */
/* _ux_utility_string_length_check Check C string and return */
/* its length if null-terminated */
/* _tx_time_get Return system clock time */
/* */
/* CALLED BY */
/* */
@@ -79,6 +79,10 @@
/* refer to TX symbols instead */
/* of using them directly, */
/* resulting in version 6.1 */
+/* 30-11-2025 Mohamed Ayed Modified comment(s), */
+/* used UX prefix to refer to */
+/* TX symbols instead of using */
+/* them directly, */
/* */
/**************************************************************************/
VOID _ux_utility_debug_log(UCHAR *debug_location, UCHAR *debug_message, ULONG debug_code,
@@ -136,8 +140,8 @@ UX_INTERRUPT_SAVE_AREA
_ux_utility_memory_copy(_ux_system -> ux_system_debug_log_head, "At time : ", 10); /* Use case of memcpy is verified. */
_ux_system -> ux_system_debug_log_head += 10;
- /* Get the time value from TX. */
- current_time = _tx_time_get();
+ /* Get the time value. */
+ current_time = _ux_utility_time_get();
/* Reset the value of the length.*/
parameter_length = 0;
@@ -62,7 +62,7 @@
/* _ux_utility_string_length_check Check C string and return */
/* its length if null-terminated */
-/* _tx_time_get Return system clock time */
+/* _ux_utility_time_get Return system clock time */
/* */
/* CALLED BY */